from typing import overload
import ghidra.framework.model
import ghidra.program.model.address
import java.lang


class ProgramChangeRecord(ghidra.framework.model.DomainObjectChangeRecord):
    """
    Event data for a DomainObjectChangeEvent generated by a Program.
    """





    @overload
    def __init__(self, eventType: ghidra.program.util.ProgramEvent, oldValue: object, newValue: object): ...

    @overload
    def __init__(self, eventType: ghidra.program.util.ProgramEvent, start: ghidra.program.model.address.Address, end: ghidra.program.model.address.Address, affected: object, oldValue: object, newValue: object):
        """
        Construct a new ProgramChangeRecord; any of the Address or
         Object params may be null, depending on what the type param is.
        @param eventType event type
        @param start starting address that is affected by the event
        @param end ending address that is affected by the event
        @param affected the object that was affected by this change, if applicable
        @param oldValue original value
        @param newValue new value
        """
        ...



    def equals(self, __a0: object) -> bool: ...

    def getClass(self) -> java.lang.Class: ...

    def getEnd(self) -> ghidra.program.model.address.Address:
        """
        Get the end address of the affected addresses of this change or null if not applicable.
        @return the end address of the effected address of this change
        """
        ...

    def getEventType(self) -> ghidra.framework.model.EventType:
        """
        Returns the event type for this change.
        @return the event type for this change
        """
        ...

    def getNewValue(self) -> object:
        """
        Return the new value for this event or null if not applicable.
        @return the old value or null if not applicable for this event.
        """
        ...

    def getObject(self) -> object:
        """
        Return the object that is the subject of this change record.
        @return the object affected or null if not applicable
        """
        ...

    def getOldValue(self) -> object:
        """
        Return the old value for this event or null if not applicable.
        @return the old value or null if not applicable
        """
        ...

    def getStart(self) -> ghidra.program.model.address.Address:
        """
        Get the start address of the affected addresses of this change or null if not applicable.
        @return the start address of the effected address of this change
        """
        ...

    def hashCode(self) -> int: ...

    def notify(self) -> None: ...

    def notifyAll(self) -> None: ...

    def toString(self) -> unicode: ...

    @overload
    def wait(self) -> None: ...

    @overload
    def wait(self, __a0: long) -> None: ...

    @overload
    def wait(self, __a0: long, __a1: int) -> None: ...

    @property
    def end(self) -> ghidra.program.model.address.Address: ...

    @property
    def object(self) -> object: ...

    @property
    def start(self) -> ghidra.program.model.address.Address: ...